==> paraview-5.9.1-5-x86_64.pkg.tar.zst: usr/include/paraview/vtkPVVTKExtensionsFiltersPythonModule.h <==

#ifndef VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT_H
#define VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT_H

#ifdef VTKPVVTKEXTENSIONSFILTERSPYTHON_STATIC_DEFINE
#  define VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT
#  define VTKPVVTKEXTENSIONSFILTERSPYTHON_NO_EXPORT
#else
#  ifndef VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT
#    ifdef VTKExtensionsFiltersPython_EXPORTS
        /* We are building this library */
#      define VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKPVVTKEXTENSIONSFILTERSPYTHON_NO_EXPORT
#    define VTKPVVTKEXTENSIONSFILTERSPYTHON_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED
#  define VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED_EXPORT
#  define VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED_EXPORT VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED
#endif

#ifndef VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED_NO_EXPORT
#  define VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED_NO_EXPORT VTKPVVTKEXTENSIONSFILTERSPYTHON_NO_EXPORT VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKPVVTKEXTENSIONSFILTERSPYTHON_NO_DEPRECATED
#    define VTKPVVTKEXTENSIONSFILTERSPYTHON_NO_DEPRECATED
#  endif
#endif

#endif /* VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT_H */

==> paraview-6.0.1-2-x86_64.pkg.tar.zst: usr/include/paraview/vtkPVVTKExtensionsFiltersPythonModule.h <==

#ifndef VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT_H
#define VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT_H

#ifdef VTKPVVTKEXTENSIONSFILTERSPYTHON_STATIC_DEFINE
#  define VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT
#  define VTKPVVTKEXTENSIONSFILTERSPYTHON_NO_EXPORT
#else
#  ifndef VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT
#    ifdef VTKExtensionsFiltersPython_EXPORTS
        /* We are building this library */
#      define VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKPVVTKEXTENSIONSFILTERSPYTHON_NO_EXPORT
#    define VTKPVVTKEXTENSIONSFILTERSPYTHON_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED
#  define VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED_EXPORT
#  define VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED_EXPORT VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED
#endif

#ifndef VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED_NO_EXPORT
#  define VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED_NO_EXPORT VTKPVVTKEXTENSIONSFILTERSPYTHON_NO_EXPORT VTKPVVTKEXTENSIONSFILTERSPYTHON_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKPVVTKEXTENSIONSFILTERSPYTHON_NO_DEPRECATED
#    define VTKPVVTKEXTENSIONSFILTERSPYTHON_NO_DEPRECATED
#  endif
#endif

/* VTK-HeaderTest-Exclude: vtkPVVTKExtensionsFiltersPythonModule.h */

/* Include ABI Namespace */
#include "vtkABINamespace.h"

#endif /* VTKPVVTKEXTENSIONSFILTERSPYTHON_EXPORT_H */
